/*
	desc      : libvlc test application (ref : http://wiki.videolan.org/LibVLC_Tutorial)
	author    : raphael smart
	date      : october 2012

	licence/disclaimer:

	This software is provided 'as-is', without any express or implied warranty.
	In no event will the author be held liable for any damages arising from
	the use of this software.
*/
namespace testvlc
constant __MODULENAME__ = "testvlc"

include std/os.e
include std/filesys.e
include std/cmdline.e
include std/map.e
include std/console.e
include std/text.e     as txt

include include/libvlc.e as vlc

enum 

	false = 0,
	true

procedure listFilters(sequence moduleList)
	for i = 1 to length(moduleList) do
		printf(1, "%s - %s %s\n", { moduleList[i][1], moduleList[i][2], txt:wrap(moduleList[i][$]) })
	end for
end procedure

procedure filterInfo()
	sequence audioFilt = vlc:audioFilters(vlc)
	sequence videoFilt = vlc:videoFilters(vlc)
	listFilters(audioFilt)
	listFilters(videoFilt)
end procedure

procedure mediaInfo(atom media)
	display(vlc:mediaInfo(media))
end procedure

	--// main

	--// parse command line

	sequence cmdopts = 
	{
		{ "f",  0, "video/audio filename",            { HAS_PARAMETER, "filename", MANDATORY } }
	}

	map      opts     = cmd_parse(cmdopts)
	sequence fileName = map:get(opts, "f", "")

	vlc:assert(file_exists(fileName), "file '" & fileName & "' does not exist")

	display("version   = [1]", { vlc:version() })
	display("compiler  = [1]", { vlc:compiler() })
	display("changeset = [1]", { vlc:changeset() })

	/*
		VLC_PLUGINP_PATH

		this can be set in to the VLC plugins directory
		using the shell environment prior to running this program

		eg:
				Linux   :

						$ export VLC_PLUGIN_PATH=/usr/lib/vlc/plugins

						$ ./testvlc <-f filename>

				Windows :

					C:\ SET VLC_PLUGIN_PATH="C:\Program Files\VideoLAN\VLC\plugins

					C:\testvlc.exe <-f filename>

	*/

	display("VLC_PLUGIN_PATH = [1]", { getenv("VLC_PLUGIN_PATH") })

	/* 
		load VLC engine

		see vlc docs for additional command line parameters
	*/

	sequence vlcargv =
	{
		"-I", 
		"dummy"
	}
	
	atom vlc = vlc:new(vlcargv)

	--// create a new item

	atom media = vlc:mediaNewPath(vlc, fileName)

	vlc:assert(media > 0, "could not initialise vlc media")

	--// create a media player playing environment

	atom mediaplayer = vlc:mediaPlayerNewFromMedia(media)

	vlc:assert(mediaplayer > 0, "could not initialise vlc media player")

	vlc:mediaRelease(media)

	--// play the media player for [n] seconds

	vlc:mediaPlayerPlay(mediaplayer)

	sleep(20)

	--// stop

	vlc:mediaPlayerStop(mediaplayer)

	--// clean up

	vlc:mediaPlayerRelease(mediaplayer)

	vlc:release(vlc)
